@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "text_imp.h"
 
@@ -74,7 +74,7 @@ const uint TextImp::numberOfProperties() const
 const QCStringList TextImp::propertiesInternalNames() const
 {
   QCStringList ret = Parent::propertiesInternalNames();
-  ret << "text";
+  ret << "kig_text";
   return ret;
 }
 
